
dilithium-20171125
Public Domain

Authors: Léo Ducas,
         Eike Kiltz,
         Tancrède Lepoint,
         Vadim Lyubashevsky,
         Gregor Seiler,
         Peter Schwabe,
         Damien Stehlé

For Keccak and the random number generator 
we are using public-domain code from sources 
and by authors listed in comments on top of 
the respective files.
